==> durt-0.1.4.tar.gz: test/hd_wallets_test.dart <==
import 'package:test/test.dart';
import 'package:durt/src/crypto/hd_wallet.dart';

void main() {
  group('wallets', () {
    test('Generate HD wallet', () {
      const String mnemonicLang = 'french';
      final int derivation = 3;

      print('------------------\n HD Wallet Test\n------------------\n');
      var mnemonicTest = generateMnemonic(lang: mnemonicLang);
      expect(mnemonicTest.split(' ').length, 12);

      // String mnemonic =
      //     "mauve victoire victoire cupide chaleur minimal punaise utopie plumage géologie quitter chaise";
      final mnemonic =
          'guide chagrin honorer grand tablier sortir analyse lavoir circuler tarder exigence séance';
      // final mnemonic =
      //     'tongue cute mail fossil great frozen same social weasel impact brush kind';
      // final mnemonic =
      //     'acquire flat utility climb filter device liberty beyond matrix satisfy metal essence';

      HdWallet _hdWallet = HdWallet.fromMnemonic(mnemonic);

      String pubkey = _hdWallet.getPubkey(derivation);

      String message = "blabla test";
      var signature = _hdWallet.sign(message, derivation: derivation);
      bool isOK =
          _hdWallet.verifySign(message, signature, derivation: derivation);

      print('Mnemonic: ' + mnemonic);
      print('Pubkey N°$derivation: ' + pubkey);
      print('Is signature OK ? : ' + isOK.toString());

      expect(pubkey, 'GauM5qWiX1uzqSdRRM51it95sMdadLnsNrRKSoMQU6xd');
      expect(isOK, true);
    });
  });
}

==> durt-0.1.6.tar.gz: test/hd_wallets_test.dart <==
import 'package:durt/durt.dart';
import 'package:test/test.dart';

void main() {
  group('wallets', () {
    test('Generate HD wallet', () async {
      const String mnemonicLang = 'french';
      final int derivation = 3;

      print('------------------\n HD Wallet Test\n------------------\n');
      final mnemonicTest = generateMnemonic(lang: mnemonicLang);
      expect(mnemonicTest.split(' ').length, 12);

      // String mnemonic =
      //     "mauve victoire victoire cupide chaleur minimal punaise utopie plumage géologie quitter chaise";
      final mnemonic =
          'guide chagrin honorer grand tablier sortir analyse lavoir circuler tarder exigence séance';
      // final mnemonic =
      //     'tongue cute mail fossil great frozen same social weasel impact brush kind';
      // final mnemonic =
      //     'acquire flat utility climb filter device liberty beyond matrix satisfy metal essence';

      HdWallet _hdWallet = HdWallet.fromMnemonic(mnemonic);

      String pubkey = _hdWallet.getPubkey(derivation);

      String message = "blabla test";
      final signature = _hdWallet.sign(message, derivation: derivation);
      bool isOK =
          _hdWallet.verifySign(message, signature, derivation: derivation);

      print('Mnemonic: ' + mnemonic);
      print('Pubkey N°$derivation: ' + pubkey);
      print('Is signature OK ? : ' + isOK.toString());

      expect(pubkey, 'GauM5qWiX1uzqSdRRM51it95sMdadLnsNrRKSoMQU6xd');
      expect(isOK, true);

      final dewifWallet =
          await Dewif().generateDewif(mnemonic, 'ABCDE', lang: mnemonicLang);
      final reHdWallet =
          HdWallet.fromDewif(dewifWallet.dewif, 'ABCDE', lang: mnemonicLang);

      expect(reHdWallet.getPubkey(derivation),
          'GauM5qWiX1uzqSdRRM51it95sMdadLnsNrRKSoMQU6xd');
    });
  });
}
